# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Copyright (C) 2010 Jose Ernesto Davila Pantoja <josernestodavila@ubuntu.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import sys
import os
import gtk
import gobject
import re

from pizzabashlog.pizzabashlogconfig import getdatapath

class SaveDialog(gtk.Dialog):
    __gtype_name__ = "SaveDialog"

    def __init__(self):
        """__init__ - This function is typically not called directly.
        Creation of a SaveDialog requires redeading the associated ui
        file and parsing the ui definition extrenally, 
        and then calling SaveDialog.finish_initializing().
    
        Use the convenience function NewSaveDialog to create 
        a SaveDialog object.
    
        """
        pass

    def finish_initializing(self, builder):
        """finish_initalizing should be called after parsing the ui definition
        and creating a SaveDialog object with it in order to finish
        initializing the start of the new SaveDialog instance.
    
        """
        #get a reference to the builder and set up the signals
        self.builder = builder
        self.builder.connect_signals(self)
        
        #Agregar al combobox1 los nombres de las distros más usadas en .ni
        store = gtk.ListStore(gobject.TYPE_STRING)
        store.append(['Ubuntu'])
        store.append(['Debian'])
        store.append(['Fedora'])
        store.append(['openSuSE'])
        store.append(['Mandriva'])
        store.append(['No Aplica'])
        
        self.combo = self.builder.get_object("combobox1")
        self.combo.set_model(store)
        cell = gtk.CellRendererText()
        self.combo.pack_start(cell, True)
        self.combo.add_attribute(cell, 'text', 0)
        self.combo.set_active(0)
        
        #Agregar al combobox2 las maneras en que se dio cuenta del evento
        store1 = gtk.ListStore(gobject.TYPE_STRING)
        store1.append(['Twitter'])
        store1.append(['Identi.ca'])
        store1.append(['Facebook'])
        store1.append(['Correo Electrónico'])
        store1.append(['Posol'])
        store1.append(['Amigos'])
        store1.append(['Otros'])
        
        self.combo1 = self.builder.get_object("combobox2")
        self.combo1.set_model(store1)
        cell1 = gtk.CellRendererText()
        self.combo1.pack_start(cell1, True)
        self.combo1.add_attribute(cell1, 'text', 0)
        self.combo1.set_active(0)
        
        #Agregar a cboGenero los géneros Masculino y Femenino
        lstGenero = gtk.ListStore(gobject.TYPE_STRING)
        lstGenero.append(['Femenino'])
        lstGenero.append(['Masculino'])
        
        self.cboGenero = self.builder.get_object("cboGenero")
        self.cboGenero.set_model(lstGenero)
        cell2 = gtk.CellRendererText()
        self.cboGenero.pack_start(cell2, True)
        self.cboGenero.add_attribute(cell2, 'text', 0)
        self.cboGenero.set_active(0)
        
    def ok(self, widget, data=None):
        """ok - The user has elected to save the changes.
        Called before the dialog returns gtk.RESONSE_OK from run().

        """
        pass

    def cancel(self, widget, data=None):
        """cancel - The user has elected cancel changes.
        Called before the dialog returns gtk.RESPONSE_CANCEL for run()

        """         
        pass
    
    def check_ready_save(self, widget, data=None):
        nombre = self.builder.get_object("entry1")
        email = self.builder.get_object("entry2")
        combo = self.builder.get_object("combobox1")
        
        pattern = re.compile("^.+\\@(\\[?)[a-zA-Z0-9\\-\\.]+\\.([a-zA-Z]{2,3}|[0-9]{1,3})(\\]?)$")
        
        if (not self.is_empty(nombre)) and (combo.get_active() != -1) and (not self.is_empty(email)) and (pattern.match(email.get_text()) != None):
            self.builder.get_object("button1").set_sensitive(True)
        else:
            self.builder.get_object("button1").set_sensitive(False)     
    
    def is_empty(self, te):
        text = te.get_text()
        if text == "":
            te.set_tooltip_text("El campo no puede estar vacío")
            return True
        te.set_tooltip_text(None)
        return False
    
    @property
    def get_name(self):
        return self.builder.get_object("entry1").get_text()
    
    @property
    def get_email(self):
        return self.builder.get_object("entry2").get_text()
    
    @property
    def get_genero(self):
        return self.builder.get_object("cboGenero").get_active_text()
    
    @property
    def get_distro(self):
        return self.builder.get_object("combobox1").get_active_text()
    
    @property
    def get_origen(self):
        return self.builder.get_object("combobox2").get_active_text()

def NewSaveDialog():
    """NewSaveDialog - returns a fully instantiated
    dialog-camel_case_nameDialog object. Use this function rather than
    creating SaveDialog instance directly.
    
    """

    #look for the ui file that describes the ui
    ui_filename = os.path.join(getdatapath(), 'ui', 'SaveDialog.ui')
    if not os.path.exists(ui_filename):
        ui_filename = None

    builder = gtk.Builder()
    builder.add_from_file(ui_filename)    
    dialog = builder.get_object("save_dialog")
    dialog.finish_initializing(builder)
    return dialog

if __name__ == "__main__":
    dialog = NewSaveDialog()
    dialog.show()
    gtk.main()

